@@ -1,6 +1,6 @@
 package Fennec::Assert::Core::Anonclass;
 BEGIN {
-  $Fennec::Assert::Core::Anonclass::VERSION = '0.029';
+  $Fennec::Assert::Core::Anonclass::VERSION = '0.030';
 }
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ util anonclass => sub {
     my $self = bless( \$pkg, __PACKAGE__ );
 
     for my $load ( ___as_list( $proto{ use })) {
-        $self->use( $load );
+        $self->use( ref($load) ? @$load : $load );
     }
 
     return $self;
